@@ -3,6 +3,7 @@ import ctypes
 
 import numba
 import numpy as np
+from mpi4py.MPI import ANY_SOURCE, ANY_TAG
 
 from numba_mpi.common import _MPI_Comm_World_ptr, _MpiStatusPtr, libmpi, send_recv_args
 from numba_mpi.utils import _mpi_addr, _mpi_dtype
@@ -15,7 +16,7 @@ _MPI_Recv.argtypes = send_recv_args + [
 
 
 @numba.njit()
-def recv(data, source, tag):
+def recv(data, source=ANY_SOURCE, tag=ANY_TAG):
     """file containing wrapper for MPI_Recv (writes data directly if `data` is contiguous, otherwise
     allocates a buffer and later copies the data into non-contiguous `data` array).
     Returns integer status code (0 == MPI_SUCCESS)"""
